package com.example.basketballmatchmanager.db;

import java.util.ArrayList;
import java.util.List;

import android.content.Context;
import android.content.ContentValues;
import android.database.Cursor;
import android.util.Log;

public class Club extends SQLiteDBManager {
	
	protected int id;
	protected String name;
	protected String descrip;
	protected String province;
	protected String town;
	protected String court;
	private String creationUser;
	private String creationDate;
	
	/** Constructor de classe 1 */
	public Club (Context context) {
		super(context);
	}
	
	/** Constructor de classe 2*/
	public Club (Context context, String name, String descrip, String province, 
			String town, String court, String user) {
		
		super(context);
		this.name = name;
		this.descrip = descrip;
		this.province = province;
		this.town = town;
		this.court = court;
		this.creationUser = user;
		this.creationDate = CurrentDate(); 
	}
	
	/**
	 * Mtode per afegir un nou registre.
	 * @return BOOLEAN TRUE si ha tingut xit FALSE cas contrari
	 * */
	public boolean addRegister() {
		
		if (name.length() > 0) {
			ContentValues contentValues = new ContentValues();
			contentValues.put(DBHelper.CN_NAME, this.name);			
			contentValues.put(DBHelper.CN_DESCRIPTION, this.descrip);
			contentValues.put(DBHelper.CN_PROVINCE, this.province);
			contentValues.put(DBHelper.CN_TOWN, this.town);
			contentValues.put(DBHelper.CN_COURT, this.court);
			contentValues.put(DBHelper.CN_USER, this.creationUser);
			contentValues.put(DBHelper.CN_CREATION, this.creationDate);
			Log.i("SQLite", "Intent de enregistrar un club de basquetbol");
			return (DBObject.insert(DBHelper.TABLE_NAME_CLUBS, null, contentValues)!=-1)?true:false;
			} 
		else
			return false;
	}
	
	/**
	 * Donat un Cursor amb els registres de la base de dades, dona format i retorna el resultat.
	 * @return ArrayList<String>
	 * */
	public ArrayList<Item> getListItem(Cursor cursor) {
		
		ArrayList<Item> listData = new ArrayList<Item>();
		String aux = "";
		
		if (cursor.moveToFirst()) {
			do {
				//aux += "ID: [" + cursor.getInt(0) + "]\r\n";
				aux += "Nom: " + cursor.getString(1) + "\r\n";
				aux += "Descripci: " + cursor.getString(2) + "\r\n";
				aux += "Provincia: " + cursor.getString(3) + "\r\n";
				aux += "Poblaci: " + cursor.getString(4) + "\r\n";
				aux += "Pavell: " + cursor.getString(5) + "\r\n";
				//aux += "Usuari: " + cursor.getString(6) +  "\r\n";
				//aux += "Data creaci: " + cursor.getString(7) + "";
				Item item = new Item (cursor.getString(0), aux);
				listData.add(item);
				aux = "";
			} while (cursor.moveToNext());
		}
		return listData;
	}
	
	/**
	 * Retorna una lliga per l'identificador autonumric.
	 * */
	public Cursor getClubForId(int id) {
		return DBObject.query(DBHelper.TABLE_NAME_CLUBS, 
				new String[] {
				DBHelper.CN_ID, 
				DBHelper.CN_NAME,
				DBHelper.CN_DESCRIPTION, 
				DBHelper.CN_PROVINCE, 
				DBHelper.CN_TOWN,
				DBHelper.CN_COURT, 
				DBHelper.CN_USER,
				DBHelper.CN_CREATION},
				DBHelper.CN_ID + " = " + id, null, null, null, null);
	}
	
    public String getCourt(String id){      
    	
        String selectQuery = "SELECT " + DBHelper.CN_COURT + " FROM " + DBHelper.TABLE_NAME_CLUBS 
        		+ " C INNER JOIN " + DBHelper.TABLE_NAME_TEAMS + " T ON C." + DBHelper.CN_ID 
        		+ " = T." + DBHelper.CN_CLUB + " WHERE T." + DBHelper.CN_ID + " = " + id;
        return getStringQuery(selectQuery);
    }
	
	/**
	 * Recupera tots els registres de la taula indicada de la base de dades
	 * @return Cursor
	 * */
	public Cursor getRegisters() {
		return DBObject.query(DBHelper.TABLE_NAME_CLUBS, 
				new String[] {
				DBHelper.CN_ID, 
				DBHelper.CN_NAME,
				DBHelper.CN_DESCRIPTION, 
				DBHelper.CN_PROVINCE, 
				DBHelper.CN_TOWN,
				DBHelper.CN_COURT,
				DBHelper.CN_USER,
				DBHelper.CN_CREATION}, null, null, null, null, null);					
	}
	
	public String toString() {
		return ("Club: " + this.name + "\n");
	}
}
