package com.example.basketballmatchmanager.db;

import java.util.ArrayList;
import java.util.List;
import android.content.Context;
import android.content.ContentValues;
import android.database.Cursor;
import android.util.Log;

public class League extends SQLiteDBManager {
	
	private int id;
	private String name;
	private String group;
	private String descrip;
	private String level;
	private Boolean womenLeague;
	private Boolean spanishFed;
	private String comunity;
	private String creationUser;
	private String creationDate;
	
	/** Constructor de classe 1 */
	public League (Context context) {
		super(context);
	}
	
	/** Constructor de classe 2*/
	public League (Context context, String name, String group, String descrip, String level, Boolean womenLeague, 
			Boolean spanishFed, String comunity, String user) {
		
		super(context);
		this.name = name;
		this.group = group;
		this.descrip = descrip;
		this.level = level;
		this.womenLeague = womenLeague;
		this.spanishFed = spanishFed;
		this.comunity = comunity;
		this.creationUser = user;
		this.creationDate = CurrentDate(); 
	}
	
	/**
	 * Mtode per afegir un nou registre.
	 * @return BOOLEAN TRUE si ha tingut xit FALSE cas contrari
	 * */
	public boolean addRegister() {
		
		if (name.length() > 0) {
			ContentValues contentValues = new ContentValues();
			contentValues.put(DBHelper.CN_NAME, this.name);
			contentValues.put(DBHelper.CN_GROUP, this.group);
			contentValues.put(DBHelper.CN_DESCRIPTION, this.descrip);
			contentValues.put(DBHelper.CN_LEVEL, this.level);
			contentValues.put(DBHelper.CN_WOMEN, this.womenLeague);
			contentValues.put(DBHelper.CN_SPAINFED, this.spanishFed);
			contentValues.put(DBHelper.CN_COMUNITY, this.comunity);
			contentValues.put(DBHelper.CN_USER, this.creationUser);
			contentValues.put(DBHelper.CN_CREATION, this.creationDate);
			Log.i("SQLite", "Intent de enregistrar una lliga");
			return (DBObject.insert(DBHelper.TABLE_NAME_LEAGUES, null, contentValues)!=-1)?true:false;
			} 
		else
			return false;
	}
	
	/**
	 * Donat un Cursor amb els registres de la base de dades, dona format i retorna el resultat.
	 * @return ArrayList<String>
	 * */
	public ArrayList<Item> getListItem(Cursor cursor) {
		
		ArrayList<Item> listData = new ArrayList<Item>();
		String aux = "";
		
		if (cursor.moveToFirst()) {
			do {
				//aux += "ID: [" + cursor.getInt(0) + "]\r\n";
				aux += "Nom: " + cursor.getString(1) + "\r\n";
				aux += "Grup: " + cursor.getString(2) + "\r\n";
				aux += "Descripci: " + cursor.getString(3) + "\r\n";
				aux += "Categoria: " + cursor.getString(4) + "\r\n";
				aux += "Gnere: " + ((Integer.parseInt(cursor.getString(5))==0)?"Lliga masculina":"Lliga femenina") + "\r\n";
				aux += "Federaci: " + ((Integer.parseInt(cursor.getString(6))==0)?"Autonmica":"Espanyola") + "\r\n";
				if (!cursor.getString(7).equals("")) aux += "Comunitat: " + cursor.getString(7) +  "\r\n";
				//aux += "Usuari: " + cursor.getString(8) +  "\r\n";
				//aux += "Data creaci: " + cursor.getString(9) + "";
				Item item = new Item (cursor.getString(0), aux);
				listData.add(item);
				aux = "";
			} while (cursor.moveToNext());
		}
		return listData;
	}
	
	/**
	 * Retorna una lliga per l'identificador autonumric.
	 * */
	public Cursor getLeagueForId(int id) {
		return DBObject.query(DBHelper.TABLE_NAME_LEAGUES, 
				new String[] {
				DBHelper.CN_ID, 
				DBHelper.CN_NAME,
				DBHelper.CN_GROUP,
				DBHelper.CN_DESCRIPTION, 
				DBHelper.CN_LEVEL, 
				DBHelper.CN_WOMEN,
				DBHelper.CN_SPAINFED, 
				DBHelper.CN_COMUNITY,
				DBHelper.CN_USER,
				DBHelper.CN_CREATION},
				DBHelper.CN_ID + " = " + id, null, null, null, null);
	}
	
    public List<Item> getSpinnerLeague(){      	
        String selectQuery = "SELECT * FROM " + DBHelper.TABLE_NAME_LEAGUES;
        return getCursorQuery(selectQuery, true);
    }	
	
    public List<Item> getSpinnerLeague(String level, String women){      	
        String selectQuery = "SELECT * FROM " + DBHelper.TABLE_NAME_LEAGUES + " WHERE " 
        		+ DBHelper.CN_LEVEL + " = '" + level + "' AND " + DBHelper.CN_WOMEN + " = '" + women + "'";
        return getCursorQuery(selectQuery, true);
    }
	
	/**
	 * Recupera tots els registres de la taula indicada de la base de dades
	 * @return Cursor
	 * */
	public Cursor getRegisters() {
		return DBObject.query(DBHelper.TABLE_NAME_LEAGUES, 
				new String[] {
				DBHelper.CN_ID, 
				DBHelper.CN_NAME,
				DBHelper.CN_GROUP,
				DBHelper.CN_DESCRIPTION, 
				DBHelper.CN_LEVEL, 
				DBHelper.CN_WOMEN,
				DBHelper.CN_SPAINFED, 
				DBHelper.CN_COMUNITY,
				DBHelper.CN_USER,
				DBHelper.CN_CREATION}, null, null, null, null, null);					
	}
	
	public String toString() {
		return ("Lliga " + this.name + "\n");
	}
}
