package com.example.basketballmatchmanager.db;

import java.util.ArrayList;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.util.Log;


public class Match extends SQLiteDBManager {

	private int id_league;
	private String season;
	private int id_local;
	private int id_visitor;
	private String matchDate;
	private Boolean finished;
	private String creationUser;
	private String creationDate;
	
	/** Constructor de classe 1 */
	public Match (Context context) {
		super(context);
	}
	
	/** Constructor de classe 2*/
	public Match (Context context, int id_league, String season, int id_local, int id_visitor, 
			String matchDate, String user) {
		
		super (context);
		this.id_league = id_league;
		this.season = season;
		this.id_local = id_local;
		this.id_visitor = id_visitor;
		this.matchDate = matchDate;
		this.finished = false;
		this.creationUser = user;
		this.creationDate = CurrentDate(); 
	}
	
	/**
	 * Mtode per afegir un nou registre.
	 * @return BOOLEAN TRUE si ha tingut xit FALSE cas contrari
	 * */
	public boolean addRegister() {
		
		if (matchDate.length() > 0) {
			ContentValues contentValues = new ContentValues();
			contentValues.put(DBHelper.CN_ID_LEAGUE,this.id_league);			
			contentValues.put(DBHelper.CN_SEASON,this.season);
			contentValues.put(DBHelper.CN_ID_LOCAL,this.id_local);
			contentValues.put(DBHelper.CN_ID_VISITOR,this.id_visitor);
			contentValues.put(DBHelper.CN_MATCH_DATA,this.matchDate);
			contentValues.put(DBHelper.CN_FINISHED,this.finished);
			contentValues.put(DBHelper.CN_USER,this.creationUser);
			contentValues.put(DBHelper.CN_CREATION, this.creationDate);
			Log.i("SQLite", "Intent de enregistrar un equip");
			return (DBObject.insert(DBHelper.TABLE_NAME_TEAMS, null, contentValues)!=-1)?true:false;
			} 
		else
			return false;
	}
	
	public ArrayList<Item> getListItem(Cursor cursor) {
		 
		ArrayList<Item> listData = new ArrayList<Item>();
		String aux = "";
				
		if (cursor.moveToFirst()) {
			do {
				//aux += "ID: [" + cursor.getInt(0) + "]\r\n";
				aux += "Lliga: " + getObjectName (cursor.getString(1), DBHelper.TABLE_NAME_LEAGUES) + "\r\n";
				aux += "Temporada: " + cursor.getString(2) + "\r\n";
				aux += "Equip local: " + getObjectName (cursor.getString(3), DBHelper.TABLE_NAME_TEAMS) + "\r\n";
				aux += "Equip visitant: " + getObjectName (cursor.getString(4), DBHelper.TABLE_NAME_TEAMS) + "\r\n";
				aux += "Data: " + cursor.getString(5) + "\r\n";
				aux += "Estat del partit: " + ((Integer.parseInt(cursor.getString(6))==0)?"No finalitzat":"Fnalitzat");
				Item item = new Item (cursor.getString(0), aux);
				listData.add(item);
				aux = "";
			} while (cursor.moveToNext());
		}
		return listData;
	}
	
	private String getObjectName(String id, String TableName) {
		
		String sName = "";
		String[] args={id};
		Cursor cursor = DBObject.rawQuery("SELECT " + DBHelper.CN_NAME 
				+ " FROM " + TableName 
				+ " WHERE " + DBHelper.CN_ID + " = ?" , args);
		
		if (cursor.moveToFirst()) {
			sName = cursor.getString(0);
		}
		return sName;
	}
	
	/**
	 * Recupera el registres segons el id_leagueentificador de TEAM
	 * @return Cursor
	 * */
	public Cursor getMatchForId(int id) {
		return DBObject.query(DBHelper.TABLE_NAME_MATCHES, 
				new String[] {
				DBHelper.CN_ID,
				DBHelper.CN_ID_LEAGUE,			
				DBHelper.CN_SEASON,
				DBHelper.CN_ID_LOCAL,
				DBHelper.CN_ID_VISITOR,
				DBHelper.CN_MATCH_DATA,
				DBHelper.CN_FINISHED,
				DBHelper.CN_USER,
				DBHelper.CN_CREATION}, 
				DBHelper.CN_ID + " = " + id, null, null, null, null);		
	}
	
	/**
	 * Recupera tots els registres de la taula indicada de la base de dades
	 * @return Cursor
	 * */
	public Cursor getRegisters() {
		return DBObject.query(DBHelper.TABLE_NAME_MATCHES, 
				new String[] {
				DBHelper.CN_ID,		
				DBHelper.CN_ID_LEAGUE,			
				DBHelper.CN_SEASON,
				DBHelper.CN_ID_LOCAL,
				DBHelper.CN_ID_VISITOR,
				DBHelper.CN_MATCH_DATA,
				DBHelper.CN_FINISHED,
				DBHelper.CN_USER,
				DBHelper.CN_CREATION}, null, null, null, null, null);		
	}
	
	public String toString() {
		return ("Partit: " + this.id_league + "/" + this.season + "/" 
				+ this.id_local + " vs " + this.id_visitor + "\n");
	}
}
