package com.example.basketballmatchmanager.db;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

import android.content.ContentValues;
import android.content.Context;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public class SQLiteHelper extends SQLiteOpenHelper {

	//Nom de la base de dades
	public static final String DB_NAME = "BasketMatchManager";
	//Versi de la base de dades
	private static final int DB_SCHEME_VERSION = 1;
	
	public final String TABLE_NAME_LEAGUES = "LEAGUES";
	public final String TABLE_NAME_CLUBS = "CLUBS";
	public final String TABLE_NAME_TEAMS = "TEAMS";
	public final String TABLE_NAME_TEAMS_X_LEAGUE = "TEAMS_X_LEAGUE";
	public final String TABLE_NAME_PLAYERS = "PLAYERS";
	public final String TABLE_NAME_PLAYER_X_TEAMS = "PLAYER_X_TEAMS";
	public final String TABLE_NAME_MATCHES = "MATCHES";
	public final String TABLE_NAME_SCORES = "SCORE";
	
	//COMMON FIELDS
	public final String CN_ID = "id";
	public final String CN_NAME = "name";
	public final String CN_DESCRIPTION = "description";
	public final String CN_SEASON = "season";
	public final String CN_LEVEL = "level";
	public final String CN_USER = "user";
	public final String CN_CREATION = "creation";
	
	public final String CN_C1P = "1PTC";
	public final String CN_C1F = "1PTF";
	public final String CN_C1T = "1PTT";
	public final String CN_C2P = "2PTC";
	public final String CN_C2F = "2PTF";
	public final String CN_C2T = "2PTT";
	public final String CN_C3P = "C3PTC";
	public final String CN_C3F = "F3PTF";
	public final String CN_C3T = "T3PTT";
	public final String CN_RD = "RD";
	public final String CN_RO = "RO";
	public final String CN_AS = "AS";
	public final String CN_REC = "REC";
	public final String CN_PER = "PER";
	public final String CN_TPF = "TPF";
	public final String CN_TPC = "TPC";
	public final String CN_FLF = "FLF";
	public final String CN_FLC = "FLC";
	public final String CN_VAL = "VAL";
	
	//LEAGUE TABLE FIELDS
	public final String CN_GROUP = "conference";
	public final String CN_WOMEN = "women";
	public final String CN_SPAINFED = "spainfed";
	public final String CN_COMUNITY = "comunity";
	
	//CLUB TABLE FIELDS
	public final String CN_LEAGUE = "league";
	public final String CN_PROVINCE = "province";
	public final String CN_TOWN = "town";
	public final String CN_COURT = "court";
	
	//TEAM TABLE FIELDS
	public final String CN_CLUB = "club";
	public final String CN_TSHIRT = "tshirt";
	public final String CN_SHORTS = "shorts";
	
	//TEAM_X_LEAGUE TABLE FIELDS
	public final String CN_ID_LEAGUE = "id_league";
	public final String CN_ID_TEAM = "id_team";

	//PLAYER TABLE FIELDS
	public final String CN_SURNAME = "surname";
	public final String CN_BIRTH = "birth";
	public final String CN_SEX = "sex";
	public final String CN_NATION = "national";
	
	//MATCH TABLE FIELDS
	public final String CN_ID_LOCAL = "local";
	public final String CN_ID_VISITOR = "visitor";
	public final String CN_MATCH_DATA = "match_data";
	public final String CN_FINISHED = "finished";
	
	//PLAYER_X_TEAM TABLE FIELDS
	public final String CN_ID_PLAYER = "id_league";
	public final String CN_ID_TEAMv = "id_team";
	
	//SCORE TABLE FIELDS
	public final String CN_ID_MATCH = "id_macth";
	public final String CN_ID_T = "visitor";
	public final String CN_MATC = "match_data";
	public final String CN_FHED = "finished";
	
	public final String CREATE_TABLE_LEAGUES = "CREATE TABLE " + TABLE_NAME_LEAGUES
			+ " (" + CN_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, " + CN_NAME
			+ " TEXT NOT NULL, " + CN_GROUP + " TEXT NULL, " + CN_DESCRIPTION
			+ " TEXT NULL, " + CN_LEVEL + " TEXT NOT NULL, " + CN_WOMEN
			+ " BOOLEAN NOT NULL, " + CN_SPAINFED + " BOOLEAN NOT NULL, " + CN_COMUNITY
			+ " TEXT NULL, " + CN_USER + " TEXT NOT NULL, " + CN_CREATION + " DATETIME);";

	public final String CREATE_TABLE_CLUBS = "CREATE TABLE " + TABLE_NAME_CLUBS
			+ " (" + CN_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, " + CN_NAME 
			+ " TEXT NOT NULL, " + CN_DESCRIPTION + " TEXT NULL, " + CN_PROVINCE 
			+ " TEXT NOT NULL, " + CN_TOWN + " TEXT NOT NULL, " + CN_COURT	
			+ " TEXT NOT NULL, " + CN_USER + " TEXT NOT NULL, " + CN_CREATION + " DATETIME);";
	
	public final String CREATE_TABLE_TEAMS = "CREATE TABLE " + TABLE_NAME_TEAMS
			+ " (" + CN_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, " + CN_CLUB + " INTEGER, " + CN_NAME 
			+ " TEXT NOT NULL, " + CN_LEVEL	+ " TEXT NOT NULL, " + CN_WOMEN	+ " BOOLEAN NOT NULL, " + CN_USER 
			+ " TEXT NOT NULL, " + CN_CREATION + " DATETIME, "	
			+ " FOREIGN KEY (" + CN_CLUB + ") REFERENCES " + TABLE_NAME_CLUBS + " (" + CN_ID + "));";
	
	public final String CREATE_TABLE_TEAMS_X_LEAGUE = "CREATE TABLE " + TABLE_NAME_TEAMS_X_LEAGUE
			+ " (" + CN_ID_TEAM + " INTEGER, " + CN_SEASON + " TEXT NOT NULL, " + CN_ID_LEAGUE 
			+ " INTEGER, " + CN_USER + " TEXT NOT NULL, " + CN_CREATION + " DATETIME, "
			+ " PRIMARY KEY (" + CN_ID_TEAM + ", " + CN_SEASON + "), "
			+ " FOREIGN KEY (" + CN_ID_TEAM + ") REFERENCES " + TABLE_NAME_TEAMS + " (" + CN_ID + "), "
			+ " FOREIGN KEY (" + CN_ID_LEAGUE + ") REFERENCES " + TABLE_NAME_LEAGUES + " (" + CN_ID + "));";
	
	public final String CREATE_TABLE_PLAYERS = "CREATE TABLE " + TABLE_NAME_PLAYERS
			+ " (" + CN_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, " + CN_NAME
			+ " TEXT NOT NULL, " + CN_SURNAME + " TEXT NOT NULL, " + CN_BIRTH
			+ " DATETIME, " + CN_SEX + " TEXT NOT NULL, " + CN_NATION
			+ " BOOLEAN NOT NULL, " + CN_USER + " TEXT NOT NULL, " + CN_CREATION + " DATETIME);";
	
	public final String CREATE_TABLE_MATCHES = "CREATE TABLE " + TABLE_NAME_MATCHES
			+ " (" + CN_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, " + CN_ID_LEAGUE 
			+ " INTEGER, " + CN_SEASON + " TEXT NOT NULL, " + CN_ID_LOCAL 
			+ " INTEGER, " + CN_ID_VISITOR + " INTEGER, " + CN_MATCH_DATA + " DATETIME, " + CN_FINISHED
			+ " BOOLEAN NOT NULL, " + CN_USER + " TEXT NOT NULL, " + CN_CREATION + " DATETIME, "
			+ " FOREIGN KEY (" + CN_ID_LEAGUE + ") REFERENCES " + TABLE_NAME_LEAGUES + " (" + CN_ID + "), "
			+ " FOREIGN KEY (" + CN_ID_LOCAL + ") REFERENCES " + TABLE_NAME_TEAMS + " (" + CN_ID + "), "
			+ " FOREIGN KEY (" + CN_ID_VISITOR + ") REFERENCES " + TABLE_NAME_TEAMS + " (" + CN_ID + "));";
	
	public final String CREATE_TABLE_PLAYER_X_TEAMS = "CREATE TABLE " + TABLE_NAME_PLAYER_X_TEAMS
			+ " (" + CN_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, " + CN_ID_PLAYER + " INTEGER, " 
			+ CN_ID_TEAM + " INTEGER, " + CN_SEASON + " TEXT NOT NULL, " + CN_C1P + " INTEGER, " 
			+ CN_C1F + " INTEGER, " + CN_C1T + " INTEGER, " + CN_C2P + " INTEGER, " 
			+ CN_C2F + " INTEGER, " + CN_C2T + " INTEGER, " + CN_C3P + " INTEGER, " 
			+ CN_C3F + " INTEGER, " + CN_C3T + " INTEGER, " + CN_RD + " INTEGER, " 
			+ CN_RO + " INTEGER, " + CN_AS + " INTEGER, " + CN_REC + " INTEGER, " 
			+ CN_PER + " INTEGER, " + CN_TPF + " INTEGER, " + CN_TPC + " INTEGER, "
			+ CN_FLF + " INTEGER, " + CN_FLC + " INTEGER, " + CN_VAL + " INTEGER, " 
			+ CN_USER + " TEXT NOT NULL, " + CN_CREATION + " DATETIME, "
			+ " FOREIGN KEY (" + CN_ID_TEAM + ") REFERENCES " + TABLE_NAME_TEAMS + " (" + CN_ID + "), "
			+ " FOREIGN KEY (" + CN_ID_PLAYER + ") REFERENCES " + TABLE_NAME_PLAYERS + " (" + CN_ID + "));";
	
	public final String CREATE_TABLE_SCORES = "CREATE TABLE " + TABLE_NAME_SCORES
			+ " (" + CN_ID_MATCH + " INTEGER, " + CN_ID_PLAYER + " TEXT NOT NULL, "  
			+ CN_C1P + " INTEGER, " 
			+ CN_C1F + " INTEGER, " + CN_C1T + " INTEGER, " + CN_C2P + " INTEGER, " 
			+ CN_C2F + " INTEGER, " + CN_C2T + " INTEGER, " + CN_C3P + " INTEGER, " 
			+ CN_C3F + " INTEGER, " + CN_C3T + " INTEGER, " + CN_RD + " INTEGER, " 
			+ CN_RO + " INTEGER, " + CN_AS + " INTEGER, " + CN_REC + " INTEGER, " 
			+ CN_PER + " INTEGER, " + CN_TPF + " INTEGER, " + CN_TPC + " INTEGER, "
			+ CN_FLF + " INTEGER, " + CN_FLC + " INTEGER, " + CN_VAL + " INTEGER, " 
			+ CN_USER + " TEXT NOT NULL, " + CN_CREATION + " DATETIME, "
			+ " PRIMARY KEY (" + CN_ID_MATCH + ", " + CN_ID_PLAYER + "), "
			+ " FOREIGN KEY (" + CN_ID_MATCH + ") REFERENCES " + TABLE_NAME_MATCHES + " (" + CN_ID + "), "
			+ " FOREIGN KEY (" + CN_ID_PLAYER + ") REFERENCES " + TABLE_NAME_PLAYER_X_TEAMS + " (" + CN_ID + "));";


	
	public final String DROP_TABLE_LEAGUES = "DROP TABLE IF EXISTS " + TABLE_NAME_LEAGUES + ";";
	public final String DROP_TABLE_CLUBS = "DROP TABLE IF EXISTS " + TABLE_NAME_CLUBS + ";";
	public final String DROP_TABLE_TEAMS = "DROP TABLE IF EXISTS " + TABLE_NAME_TEAMS + ";";
	public final String DROP_TABLE_PLAYERS = "DROP TABLE IF EXISTS " + TABLE_NAME_PLAYERS + ";";
	public final String DROP_TABLE_MATCHES = "DROP TABLE IF EXISTS " + TABLE_NAME_MATCHES + ";";
	//public final String DROP_TABLE_PLAYER_X_TEAMS = "DROP TABLE IF EXISTS " + TABLE_NAME_PLAYER_X_TEAMS + ";";
	//public final String DROP_TABLE_SCORES = "DROP TABLE IF EXISTS " + TABLE_NAME_SCORES + ";";
	

	/***  Constructor de la classe ***/
	public SQLiteHelper(Context context) {		
		super(context, DB_NAME, null, DB_SCHEME_VERSION);		
	}
	
	/**
	 * Mtode per afegir un nou registre.
	 * @return BOOLEAN TRUE si ha tingut xit FALSE cas contrari
	 * */
	public boolean addClubRegister(SQLiteDatabase db, String name, String descrip, String province, 
			String town, String court, String creationUser, String creationDate) {
		
		if (name.length() > 0) {
			ContentValues contentValues = new ContentValues();
			contentValues.put(this.CN_NAME,name);			
			contentValues.put(this.CN_DESCRIPTION,descrip);
			contentValues.put(this.CN_PROVINCE,province);
			contentValues.put(this.CN_TOWN,town);
			contentValues.put(this.CN_COURT,court);
			contentValues.put(this.CN_USER,creationUser);
			contentValues.put(this.CN_CREATION, creationDate);
			Log.i("SQLite", "Intent de enregistrar un club de basquetbol");
			return (db.insert(this.TABLE_NAME_CLUBS, null, contentValues)!=-1)?true:false;
			} 
		else
			return false;
	}
	
	/**
	 * Mtode per afegir un nou registre.
	 * @return BOOLEAN TRUE si ha tingut xit FALSE cas contrari
	 * */
	public boolean addLeagueRegister(SQLiteDatabase db, String name, String group, String descrip,
			String level, boolean womenLeague, boolean spanishFed, String comunity, 
			String creationUser, String creationDate) {
		
		if (name.length() > 0) {
			ContentValues contentValues = new ContentValues();
			contentValues.put(this.CN_NAME, name);
			contentValues.put(this.CN_GROUP, group);
			contentValues.put(this.CN_DESCRIPTION, descrip);
			contentValues.put(this.CN_LEVEL, level);
			contentValues.put(this.CN_WOMEN, womenLeague);
			contentValues.put(this.CN_SPAINFED, spanishFed);
			contentValues.put(this.CN_COMUNITY, comunity);
			contentValues.put(this.CN_USER, creationUser);
			contentValues.put(this.CN_CREATION, creationDate);
			Log.i("SQLite", "Intent de enregistrar una lliga");
			return (db.insert(this.TABLE_NAME_LEAGUES, null, contentValues)!=-1)?true:false;
			} 
		else
			return false;
	}
	
	/**
	 * Mtode per afegir un nou registre.
	 * @return BOOLEAN TRUE si ha tingut xit FALSE cas contrari
	 * */
	public boolean addMatchRegister(SQLiteDatabase db, int league, String season, int local, 
			int visitor, String data, boolean finished, String creationUser, String creationDate) {
		
		if (data.length() > 0) {
			ContentValues contentValues = new ContentValues();
			contentValues.put(this.CN_ID_LEAGUE,league);			
			contentValues.put(this.CN_SEASON,season);
			contentValues.put(this.CN_ID_LOCAL,local);
			contentValues.put(this.CN_ID_VISITOR,visitor);
			contentValues.put(this.CN_MATCH_DATA,data);
			contentValues.put(this.CN_FINISHED,finished);
			contentValues.put(this.CN_USER,creationUser);
			contentValues.put(this.CN_CREATION, creationDate);
			Log.i("SQLite", "Intent de enregistrar un club de basquetbol");
			return (db.insert(this.TABLE_NAME_MATCHES, null, contentValues)!=-1)?true:false;
			} 
		else
			return false;
	}
	
	/**
	 * Mtode per afegir un nou registre.
	 * @return BOOLEAN TRUE si ha tingut xit FALSE cas contrari
	 * */
	public boolean addTeamRegister(SQLiteDatabase db, int club, String name, String level, 
			boolean women, String creationUser, String creationDate) {
		
		if (name.length() > 0) {
			ContentValues contentValues = new ContentValues();
			contentValues.put(this.CN_CLUB,club);		
			contentValues.put(this.CN_NAME,name);		
			contentValues.put(this.CN_LEVEL,level);
			contentValues.put(this.CN_WOMEN,women);
			contentValues.put(this.CN_USER,creationUser);
			contentValues.put(this.CN_CREATION, creationDate);
			Log.i("SQLite", "Intent de enregistrar un equip de basquetbol");
			return (db.insert(this.TABLE_NAME_TEAMS, null, contentValues)!=-1)?true:false;
			} 
		else
			return false;
	}
	
	
	/**
	 * Mtode per afegir un nou registre.
	 * @return BOOLEAN TRUE si ha tingut xit FALSE cas contrari
	 * */
	public boolean addPlayerRegister(SQLiteDatabase db, String name, String surname, 
			String birth, String sex, boolean nation, String creationUser, String creationDate) {
		
		if (name.length() > 0) {
			ContentValues contentValues = new ContentValues();
			contentValues.put(this.CN_NAME,name);		
			contentValues.put(this.CN_SURNAME,surname);
			contentValues.put(this.CN_BIRTH,birth);
			contentValues.put(this.CN_SEX,sex);
			contentValues.put(this.CN_NATION,nation);
			contentValues.put(this.CN_USER,creationUser);
			contentValues.put(this.CN_CREATION, creationDate);
			Log.i("SQLite", "Intent de enregistrar un equip de basquetbol");
			return (db.insert(this.TABLE_NAME_PLAYERS, null, contentValues)!=-1)?true:false;
			} 
		else
			return false;
	}
	
	private void addDefaultRegisters(SQLiteDatabase db) {
		
		//LEAGUES
		addLeagueRegister(db, "ACB", "", "Asociacin de Clubes de Baloncesto", "Senior", false, true, "", "Guest", CurrentDate());
		addLeagueRegister(db, "LEB", "ADECCO ORO", "Liga Espanola de Baloncesto", "Senior", false, true, "", "Guest", CurrentDate());
		addLeagueRegister(db, "LEB", "ADECCO PLATA", "Liga Espanola de Baloncesto", "Senior", false, true, "", "Guest", CurrentDate());
		addLeagueRegister(db, "EBA", "A", "Liga Espanola de Baloncesto Amateur", "Senior", false, true, "Galcia", "Guest", CurrentDate());
		addLeagueRegister(db, "EBA", "B", "Liga Espanola de Baloncesto Amateur", "Senior", false, true, "Madrid", "Guest", CurrentDate());
		addLeagueRegister(db, "EBA", "C", "Liga Espanola de Baloncesto Amateur", "Senior", false, true, "Catalunya", "Guest", CurrentDate());
		addLeagueRegister(db, "EBA", "D", "Liga Espanola de Baloncesto Amateur", "Senior", false, true, "Andalusia", "Guest", CurrentDate());
		addLeagueRegister(db, "FEMENINA", "1", "Liga Femenina", "Senior", true, true, "", "Guest", CurrentDate());
		addLeagueRegister(db, "FEMENINA", "2", "Liga Femenina 2", "Senior", true, true, "", "Guest", CurrentDate());
		addLeagueRegister(db, "JUNIOR PREFERENT", "Grup 1", "Junior Preferent", "Junior", false, true, "", "Guest", CurrentDate());
		
		//CLUBS
		addClubRegister(db, "F.C.Barcelona", "Ftbol Club Barcelona Baloncesto", "Barcelona", "Barcelona", "Palau Blaugrana", "Guest", CurrentDate());
		addClubRegister(db, "Real Madrid", "Real Madrid Baloncesto", "Madrid", "Madrid", "Palacio de los Deportes", "Guest", CurrentDate());
		addClubRegister(db, "Manresa Basquet", "Club Bsquet Manresa", "Barcelona", "Manresa", "Nou Congost", "Guest", CurrentDate());
		addClubRegister(db, "Club Joventut Badalona", "CJB Badalona Basquet", "Barcelona", "Badalona", "Palau Olmpic", "Guest", CurrentDate());
		addClubRegister(db, "C.B.Santfeliu", "Club Basquet Santfeliu", "Barcelona", "Sant Feliu de Llobregat", "Joan Carles Navarro", "Guest", CurrentDate());
		addClubRegister(db, "C.B.Granollers", "Club Basquet Granollers", "Barcelona", "Granollers", "Les Franqueses", "Guest", CurrentDate());
		addClubRegister(db, "C.B.Santa Cruz", "Club Basquet Santa Cruz", "Santa Cruz Tenerife", "Santa Cruz de Tenerife", "Palacio Municipal de Deportes", "Guest", CurrentDate());
		addClubRegister(db, "A.E.C COLLBLANC", "A.E.C COLLBLANC", "Barcelona", "Hositalet", "Fum d'Estampa", "Guest", CurrentDate());
		addClubRegister(db, "SABADELL SANT NICOLAU", "SABADELL SANT NICOLAU	", "Barcelona", "Sabadell", "Pavell de Sant Nicolau", "Guest",	CurrentDate());
		addClubRegister(db, "J.A.C. SANTS", "J.A.C. SANTS", "Barcelona", "Barcelona", "Pavell Olmpic Espanya Industrial", "Guest", CurrentDate());
		addClubRegister(db, "C.B. LHOSPITALET", "C.B. LHOSPITALET", "Barcelona", "Hospitalet", "Nou Pavell del Centre", "Guest", CurrentDate());
		addClubRegister(db, "C.B. QUART", "C.B. QUART", "Gerona", "Quart", "Pavell Municipal de Quart", "Guest", CurrentDate());
		addClubRegister(db, "C.B. CORNELLA", "C.B. CORNELLA", "Barcelona", "Cornell", "Parc Esportiu Llobregat", "Guest", CurrentDate());
		addClubRegister(db, "B.C. MARTORELL", "B.C. MARTORELL", "Barcelona", "Martorell", "Felix Duran i Camenyeres", "Guest", CurrentDate());

		//TEAMS
		addTeamRegister(db, 1, "Regal Barcelona", "Senior", false, "Guest", CurrentDate());
		addTeamRegister(db, 1, "F.C.Barcelona", "Junior", false, "Guest", CurrentDate());
		addTeamRegister(db, 1, "Santfeliuenc F.C.Barcelona", "Senior", true, "Guest", CurrentDate());
		addTeamRegister(db, 3, "La Bruixa Dor", "Senior", false, "Guest", CurrentDate());
		addTeamRegister(db, 3, "Albert Diseny", "Junior", false, "Guest", CurrentDate());
		addTeamRegister(db, 6, "Sans Granollers", "Senior", true, "Guest", CurrentDate());

		//PLAYERS
		addPlayerRegister(db, "Marcelinho", "Huertas", "25/05/83", "Hombre", false, "Guest", CurrentDate());
		addPlayerRegister(db, "Alex", "Abrines", "01/08/93", "Hombre", true, "Guest", CurrentDate());
		addPlayerRegister(db, "Doellman", "Justin", "15/08/81", "Hombre", false, "Guest", CurrentDate());
		addPlayerRegister(db, "Thomas", "Satoransky", "13/07/88", "Hombre", false, "Guest", CurrentDate());
		addPlayerRegister(db, "Ante", "Tomic", "22/11/89", "Hombre", false, "Guest", CurrentDate());
		addPlayerRegister(db, "Alex", "Hernandez", "01/01/78", "Hombre", true, "Guest", CurrentDate());
		addPlayerRegister(db, "Dimitris", "Haritopoulos", "01/08/90", "Hombre", false, "Guest", CurrentDate());
		addPlayerRegister(db, "Roger", "Grimau", "30/12/77", "Hombre", true, "Guest", CurrentDate());
		addPlayerRegister(db, "Nil", "Sabata", "11/07/98", "Hombre", true, "Guest", CurrentDate());
		addPlayerRegister(db, "Davin", "White", "22/11/88", "Hombre", false, "Guest", CurrentDate());
		
		//PLAYERS_X_TEAM

		//MATCHES
		addMatchRegister(db, 1, "14/15", 1, 4, "06/01/15", false, "Guest", CurrentDate());
		addMatchRegister(db, 10, "14/15", 5, 2, "27/03/15", false, "Guest", CurrentDate());		
		addMatchRegister(db, 9, "14/15", 6, 3, "15/02/15", false, "Guest", CurrentDate());	
	}
	
	private String CurrentDate () {
		Date date = new Date();
		DateFormat dateformat = new SimpleDateFormat ("dd/mm/yyyyy");
		return dateformat.format(date);
	}
	
	@Override
	public void onCreate(SQLiteDatabase db) {		
		 db.execSQL(this.CREATE_TABLE_LEAGUES);
		 db.execSQL(this.CREATE_TABLE_CLUBS);
		 db.execSQL(this.CREATE_TABLE_TEAMS);
		 db.execSQL(this.CREATE_TABLE_PLAYERS);
		 db.execSQL(this.CREATE_TABLE_MATCHES);
		 //db.execSQL(this.CREATE_TABLE_PLAYER_X_TEAMS);
		 //db.execSQL(this.CREATE_TABLE_SCORES);	
		 addDefaultRegisters(db);
	}

	@Override
	public void onUpgrade( SQLiteDatabase db, int oldVersion, int newVersion ) {
		// on upgrade drop older tables
		if (newVersion > oldVersion) {
			db.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME_LEAGUES + ";");
			db.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME_CLUBS + ";");
			db.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME_TEAMS + ";");
			db.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME_PLAYERS + ";");
			db.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME_MATCHES + ";");
			//db.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME_PLAYER_X_TEAMS);
			//db.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME_SCORES + ";");
			onCreate(db); // create new tables
		}
	}
}
