package com.example.basketballmatchmanager.db;

import java.util.ArrayList;
import java.util.List;

import android.content.Context;
import android.content.ContentValues;
import android.database.Cursor;
import android.util.Log;

public class Team extends SQLiteDBManager {
	
	private int id;
	private int idClub;
	private String name;
	private String level;
	private Boolean womenTeam;
	private String creationUser;
	private String creationDate;
	
	/** Constructor de classe 1 */
	public Team (Context context) {
		super(context);
	}
	
	/** Constructor de classe 2*/
	public Team (Context context, int club, String name, String level, Boolean womenTeam, String user) {
		
		super (context);
		this.idClub = club;
		this.name = name;
		this.level = level;
		this.womenTeam = womenTeam;
		this.creationUser = user;
		this.creationDate = CurrentDate(); 
	}
	
	/**
	 * Mtode per afegir un nou registre.
	 * @return BOOLEAN TRUE si ha tingut xit FALSE cas contrari
	 * */
	public boolean addRegister() {
		
		if (name.length() > 0) {
			ContentValues contentValues = new ContentValues();
			contentValues.put(DBHelper.CN_CLUB, this.idClub);
			contentValues.put(DBHelper.CN_NAME, this.name);
			contentValues.put(DBHelper.CN_LEVEL, this.level);
			contentValues.put(DBHelper.CN_WOMEN, this.womenTeam);
			contentValues.put(DBHelper.CN_USER, this.creationUser);
			contentValues.put(DBHelper.CN_CREATION, this.creationDate);
			Log.i("SQLite", "Intent de enregistrar un equip");
			return (DBObject.insert(DBHelper.TABLE_NAME_TEAMS, null, contentValues)!=-1)?true:false;
			} 
		else
			return false;
	}
	
	/**
	 * Mtode per actualitzar un registre.
	 * @return BOOLEAN TRUE si ha tingut xit FALSE cas contrari
	 * */
	public boolean updateRegister(String id) {
		
		if (name.length() > 0) {
			ContentValues contentValues = new ContentValues();
			contentValues.put(DBHelper.CN_NAME, this.name);
			Log.i("SQLite", "Intent de actualitzar un equip");
			return (DBObject.update(DBHelper.TABLE_NAME_TEAMS, contentValues, 
					DBHelper.CN_ID + " = " + id, null)!=-1)?true:false;
			} 
		else
			return false;
	}
	
	/**
	 * Mtode per afegir un nou registre.
	 * @return BOOLEAN TRUE si ha tingut xit FALSE cas contrari
	 * */
	public boolean addRegisteredTeam(String idClub, String season, String idLeague, String user) {
		
		if (name.length() > 0) {
			ContentValues contentValues = new ContentValues();
			contentValues.put(DBHelper.CN_ID_TEAM, idClub);
			contentValues.put(DBHelper.CN_SEASON, season);
			contentValues.put(DBHelper.CN_ID_LEAGUE, idLeague);
			contentValues.put(DBHelper.CN_USER, user);
			contentValues.put(DBHelper.CN_CREATION, CurrentDate());
			Log.i("SQLite", "Intent de enregistrar un equip incrit en una lliga");
			return (DBObject.insert(DBHelper.TABLE_NAME_TEAMS_X_LEAGUE, null, contentValues)!=-1)?true:false;
			} 
		else
			return false;
	}
	
	public ArrayList<Item> getListItem(Cursor cursor) {
		 
		ArrayList<Item> listData = new ArrayList<Item>();
		String aux = "";
		
		if (cursor.moveToFirst()) {
			do {
				//aux += "Id: " + cursor.getString(0) + "\r\n";
				aux += "Equip: " + cursor.getString(2) + "\r\n";
				aux += "Categoria: " + cursor.getString(3) + "\r\n";
				aux += "M/F: " + ((Integer.parseInt(cursor.getString(4))==0)?"Mascul":"Femen");
				Item item = new Item (cursor.getString(0), aux);
				listData.add(item);
				aux = "";
			} while (cursor.moveToNext());
		}
		return listData;
	}
	
	/**
	 * Recupera el registres segons el identificador de TEAM
	 * @return Cursor
	 * */
	public Cursor getTeamForClub(int idClub) {
		return DBObject.query(DBHelper.TABLE_NAME_TEAMS, 
				new String[] {
				DBHelper.CN_ID, 
				DBHelper.CN_CLUB, 								
				DBHelper.CN_NAME,
				DBHelper.CN_LEVEL, 
				DBHelper.CN_WOMEN,
				DBHelper.CN_USER,
				DBHelper.CN_CREATION}, 
				DBHelper.CN_CLUB + " = " + idClub, null, null, null, null);		
	}
	
	/**
	 * Recupera el registres segons el identificador de TEAM
	 * @return Cursor
	 * */
	public Cursor getTeamForId(int id) {
		return DBObject.query(DBHelper.TABLE_NAME_TEAMS, 
				new String[] {
				DBHelper.CN_ID, 
				DBHelper.CN_CLUB, 								
				DBHelper.CN_NAME,
				DBHelper.CN_LEVEL, 
				DBHelper.CN_WOMEN,
				DBHelper.CN_USER,
				DBHelper.CN_CREATION}, 
				DBHelper.CN_ID + " = " + id, null, null, null, null);		
	}
	
	/**
	 * Recupera tots els registres de la taula indicada de la base de dades
	 * @return Cursor
	 * */
	public Cursor getRegisters() {
		return DBObject.query(DBHelper.TABLE_NAME_TEAMS, 
				new String[] {
				DBHelper.CN_ID, 
				DBHelper.CN_CLUB, 								
				DBHelper.CN_NAME,
				DBHelper.CN_LEVEL, 
				DBHelper.CN_WOMEN,
				DBHelper.CN_USER,
				DBHelper.CN_CREATION}, null, null, null, null, null);					
	}
	
    public List<Item> getSpinnerTeam(){      	
        String selectQuery = "SELECT * FROM " + DBHelper.TABLE_NAME_TEAMS;
        return getCursorQuery(selectQuery, false);
    }	
	
	public String toString() {
		return ("Equip: " + this.name + "\n");
	}
}
